bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGammaISO.move_plates
=======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGammaISO.move_plates